# Contributing to DBPA

We love your input! We want to make contributing to DBPA as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features
- Becoming a maintainer

## Development Process

We use GitHub to host code, to track issues and feature requests, as well as accept pull requests.

1. Fork the repo and create your branch from `main`
2. If you've added code that should be tested, add tests
3. If you've changed APIs, update the documentation
4. Ensure the test suite passes
5. Make sure your code lints
6. Issue that pull request!

## Any Contributions You Make Will Be Under the MIT Software License

In short, when you submit code changes, your submissions are understood to be under the same [MIT License](http://choosealicense.com/licenses/mit/) that covers the project. Feel free to contact the maintainers if that's a concern.

## Report Bugs Using GitHub's [Issue Tracker](https://github.com/achimdehnert/dbpa/issues)

We use GitHub issues to track public bugs. Report a bug by [opening a new issue](https://github.com/achimdehnert/dbpa/issues/new); it's that easy!

## Write Bug Reports With Detail, Background, and Sample Code

**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
  - Be specific!
  - Give sample code if you can
- What you expected would happen
- What actually happens
- Notes (possibly including why you think this might be happening, or stuff you tried that didn't work)

## Use a Consistent Coding Style

* Use [Black](https://github.com/psf/black) for Python code formatting
* Use type hints for all function parameters and return values
* Follow [Google style](https://google.github.io/styleguide/pyguide.html) for docstrings
* Keep functions under 50 lines
* Keep classes under 200 lines

## License

By contributing, you agree that your contributions will be licensed under its MIT License.
